@@ -755,6 +755,19 @@ add_accelerator (GtkApplication *app,
 	gtk_application_set_accels_for_action (app, action_name, vaccels);
 }
 
+static gboolean
+show_menubar (void)
+{
+	GtkSettings *settings = gtk_settings_get_default ();
+	gboolean result;
+
+	g_object_get (settings,
+	              "gtk-shell-shows-menubar", &result,
+	              NULL);
+
+	return result;
+}
+
 static void
 gedit_app_startup (GApplication *application)
 {
@@ -797,7 +810,13 @@ gedit_app_startup (GApplication *application)
 	                                 application);
 
 	/* menus */
-	priv->hamburger_menu = get_menu_model (GEDIT_APP (application), "hamburger-menu");
+	if (!show_menubar ())
+	{
+		gtk_application_set_menubar (application, NULL);
+		priv->hamburger_menu = get_menu_model (GEDIT_APP (application),
+		                                       "hamburger-menu");
+	}
+
 	priv->notebook_menu = get_menu_model (GEDIT_APP (application), "notebook-menu");
 	priv->tab_width_menu = get_menu_model (GEDIT_APP (application), "tab-width-menu");
 	priv->line_col_menu = get_menu_model (GEDIT_APP (application), "line-col-menu");
@@ -1920,7 +1939,7 @@ _gedit_app_get_line_col_menu (GeditApp *app)
 
 GeditMenuExtension *
 _gedit_app_extend_menu (GeditApp    *app,
-                       const gchar *extension_point)
+                        const gchar *extension_point)
 {
 	GeditAppPrivate *priv;
 	GMenuModel *model;
